@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_ACCOUNTSTORAGE_KWALLET_P_H_
-#define LIBKGAPI2_ACCOUNTSTORAGE_KWALLET_P_H_
+#pragma once
 
 #include "accountstorage_p.h"
 
@@ -45,4 +44,3 @@ private:
 
 }
 
-#endif
